@@ -86,6 +86,7 @@ session_info["thread_safe"] = False
 session_info["lazy"] = True
 session_info["precision"] = None
 session_info["parallel"] = False
+session_info["checks"] = True
 
 session_info["interactive"] = sys.__stdin__.isatty()
 
@@ -110,10 +111,13 @@ def options(**kwargs):
     Define session options.
     Set the options in the session. Available options are thread_safe and lazy.
     Set thread_safe = True if hdf5 was built to be thread safe.
-    Set lazy = True if you want methods to evaluate lazy by default.
+    Set lazy = False if you want methods to evaluate non-lazily
     Set cores = n, if you want nctoolkit to process the individual files in multi-file datasets in parallel. Note this
     only applies to multi-file datasets and will not improve performance with single files.
     Set temp_dir = "/foo" if you want to change the temporary directory used by nctoolkit to save temporary files.
+    Set  = "/foo" if you want to change the temporary directory used by nctoolkit to save temporary files.
+    Set progress to "on" or "off" if you always or never want a progress bar to show when multi-file datasets are processed. This defaults to "auto", i.e.
+    nctoolkit will automatically decide whether to show a progress bar based on the size of the ensemble.
 
     Parameters
     ---------------
@@ -138,7 +142,7 @@ def options(**kwargs):
 
     """
 
-    valid_keys = ["thread_safe", "lazy", "cores", "precision", "temp_dir", "parallel"]
+    valid_keys = ["thread_safe", "lazy", "cores", "precision", "temp_dir", "parallel", "checks", "progress"]
 
     for key in kwargs:
         if key not in valid_keys:
@@ -148,6 +152,10 @@ def options(**kwargs):
             if type(kwargs[key]) is not bool:
                 raise TypeError(f"{key} should be boolean")
 
+        if key == "checks":
+            if type(kwargs[key]) is not bool:
+                raise TypeError(f"{key} should be boolean")
+
         if type(kwargs[key]) is not bool:
             if key == "temp_dir":
                 if type(kwargs[key]) is str:
@@ -156,6 +164,15 @@ def options(**kwargs):
                     session_info[key] = os.path.abspath(kwargs[key])
                     session_info["user_dir"] = True
                 return None
+            if key == "progress":
+                if kwargs[key] not in ["on", "off", "auto", "of"]:
+                    raise ValueError("progress must be one of 'on', 'off', 'auto'")
+
+                if kwargs[key] == "of": 
+                    session_info[key] = "off" 
+                else:
+                    session_info[key] = kwargs[key]
+                return None
 
             if key == "cores":
                 if type(kwargs[key]) is int:
@@ -469,6 +486,9 @@ def open_data(x=[], checks=True, **kwargs):
 
     """
 
+    if session_info["checks"] is False:
+        checks = False
+
     thredds = False
 
     ftp_details = None
@@ -1782,7 +1802,6 @@ class DataSet(object):
 
     from nctoolkit.run import run
 
-    from nctoolkit.subset import select
     from nctoolkit.subset import subset
 
     from nctoolkit.setters import set_date
@@ -1825,6 +1844,8 @@ class DataSet(object):
     from nctoolkit.toxarray import to_xarray
     from nctoolkit.toxarray import to_dataframe
 
+    from nctoolkit.tozlev import to_zlevels
+
     from nctoolkit.verticals import vertical_mean
     from nctoolkit.verticals import vertical_min
     from nctoolkit.verticals import vertical_max
